@@ -1,13 +1,8 @@
-try:
-    from airflow.providers.google.cloud.hooks.gcs import GCSHook as GoogleCloudStorageHook
-    from airflow.providers.google.cloud.sensors.gcs import GoogleCloudStorageObjectSensor
-except Exception:
-    from airflow.contrib.hooks.gcs_hook import GoogleCloudStorageHook
-    from airflow.contrib.sensors.gcs_sensor import GoogleCloudStorageObjectSensor
-from airflow.utils.decorators import apply_defaults
+from airflow.providers.google.cloud.sensors.gcs import GCSObjectExistenceSensor
+from airflow.providers.google.cloud.hooks.gcs import GCSHook as GoogleCloudStorageHook
 
 
-class GoogleCloudStorageObjectKeySensor(GoogleCloudStorageObjectSensor):
+class GoogleCloudStorageObjectKeySensor(GCSObjectExistenceSensor):
     """
     Checks for the existence of a file in Google Cloud Storage.
 
@@ -28,31 +23,29 @@ class GoogleCloudStorageObjectKeySensor(GoogleCloudStorageObjectSensor):
 
     ui_color = '#f0eee4'
 
-
-    @apply_defaults
     def __init__(self,
                  bucket,
-                 object,  # pylint:disable=redefined-builtin
-                 google_cloud_conn_id='google_cloud_default',
+                 object,
+                 gcp_conn_id='google_cloud_default',
                  delegate_to=None,
                  *args, **kwargs):
 
         super(GoogleCloudStorageObjectKeySensor, self).__init__(*args, **kwargs)
         self.bucket = bucket
         self.object = object
-        self.google_cloud_conn_id = google_cloud_conn_id
+        self.gcp_conn_id = gcp_conn_id
         self.delegate_to = delegate_to
 
     def poke(self, context):
         self.log.info('Sensor checks existence of : %s, %s', self.bucket, self.object)
         hook = GoogleCloudStorageHook(
-            google_cloud_storage_conn_id=self.google_cloud_conn_id,
+            gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to)
         return hook.exists(self.bucket, self.object)
 
     def get_object_key(self):
         hook = GoogleCloudStorageHook(
-            google_cloud_storage_conn_id=self.google_cloud_conn_id,
+            gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to)
         client = hook.get_conn()
         bucket = client.bucket(self.bucket)
